==> haskell-shakespeare-2.0.20-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.20
id: shakespeare-2.0.20-IrnfKa71ZuFIRJ8myEdIUr
key: shakespeare-2.0.20-IrnfKa71ZuFIRJ8myEdIUr
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
abi: 5b858847d4611a7611cf6a823c63d1c2
exposed: True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
import-dirs: /usr/lib/ghc-8.6.5/site-local/shakespeare-2.0.20
library-dirs: /usr/lib/ghc-8.6.5/site-local/shakespeare-2.0.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/shakespeare-2.0.20
hs-libraries: HSshakespeare-2.0.20-IrnfKa71ZuFIRJ8myEdIUr
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L base-4.12.0.0
    blaze-html-0.9.1.1-HnoxxJTQ8ftKEVcacs0b8O
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH ghc-prim-0.5.3
    parsec-3.1.13.0 process-1.6.5.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.20-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.20
id: shakespeare-2.0.20-8cxxbRsnPrE6AqhK3jA9d4
key: shakespeare-2.0.20-8cxxbRsnPrE6AqhK3jA9d4
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
abi: d1eb0c34d73913ee5b5a30fc1b9be140
exposed: True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
import-dirs: /usr/lib/ghc-8.6.5/site-local/shakespeare-2.0.20
library-dirs: /usr/lib/ghc-8.6.5/site-local/shakespeare-2.0.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/shakespeare-2.0.20
hs-libraries: HSshakespeare-2.0.20-8cxxbRsnPrE6AqhK3jA9d4
depends:
    aeson-1.4.3.0-F9e2BgjvX59JUef9tsq2ab base-4.12.0.0
    blaze-html-0.9.1.1-HnoxxJTQ8ftKEVcacs0b8O
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH ghc-prim-0.5.3
    parsec-3.1.13.0 process-1.6.5.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
